@@ -11,12 +11,16 @@ print.chacko_test <- function(x, ...) {
         "p-values:\n",
         "  Analytic p-value        : %f\n",
         "  Numeric p-value         : %f (%d permutations)\n",
+        "  Numeric mid-p value     : %f (%d permutations)\n",
         "  Tabular p-value         : %f\n"
       ),
-      paste0("p", seq_along(x$observed_data), collapse = " == "),
-      paste0("p", seq_along(x$observed_data), collapse = " <= "),
-      x[["statistic"]], p_values[["analytic"]],
-      p_values[["numeric"]], x[["n_perm"]], p_values[["tabular"]]
+      printHypothesis("p", seq_along(x$observed_data), "=="),
+      printHypothesis("p", seq_along(x$observed_data), "<="),
+      x[["statistic"]],
+      p_values[["analytic"]],
+      p_values[["numeric"]], x[["n_perm"]],
+      p_values[["numeric_mid"]], x[["n_perm"]],
+      p_values[["tabular"]]
     )
   )
 }
@@ -35,3 +39,16 @@ print.reduced_vector <- function(x, details = TRUE, ...) {
     )
   )
 }
+
+printHypothesis <- function(x_name, x_indices, operator = "==") {
+  operator <- paste0(" ", operator, " ")
+  if (length(x_indices) < 6) {
+    return(paste0(x_name, x_indices, collapse = operator))
+  } else {
+    first_idx <- 1:2
+    last_idx <- seq(length(x_indices) - 1, length(x_indices))
+    first_x <- paste0(x_name, x_indices[first_idx], collapse = operator)
+    last_x <- paste0(x_name, x_indices[last_idx], collapse = operator)
+    paste0(first_x, operator, "...", operator, last_x)
+  }
+}
