@@ -13,9 +13,13 @@ test_that("print.chacko_test() works as expected", {
   y <- permChacko(rpois(3, 5), n_perm = 30L)
   expect_output(print(y), "Test statistic \\(chisq_bar\\): 0\\.500000")
   expect_output(print(y), "Analytic p-value\\s+: 0\\.778801")
-  expect_output(print(y), "Numeric p-value\\s+: 0\\.400000 \\(30 permutation")
+  expect_output(print(y), "Numeric p-value.+: 0\\.400000 \\(30 permutation")
   expect_output(print(y), "Tabular p-value\\s+: 0\\.369550")
 })
 test_that("summary.reduced_vector() works as expected", {
   expect_output(summary(reduceVector(rpois(7, 7))), "has been reduced 3 times")
 })
+test_that("Hypothesis suppression works as expected", {
+  expect_output(print(permChacko(4:1)), "p1 == p2 == p3 == p4")
+  expect_output(print(permChacko(6:1)), "p1 == p2 == ... == p5 == p6")
+})
